"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.TracingInstrumentation = exports.getDefaultOTELInstrumentations = void 0;
var agent_core_1 = require("@grafana/agent-core");
var api_1 = require("@opentelemetry/api");
var context_zone_1 = require("@opentelemetry/context-zone");
var core_1 = require("@opentelemetry/core");
var instrumentation_1 = require("@opentelemetry/instrumentation");
var instrumentation_document_load_1 = require("@opentelemetry/instrumentation-document-load");
var instrumentation_fetch_1 = require("@opentelemetry/instrumentation-fetch");
var instrumentation_user_interaction_1 = require("@opentelemetry/instrumentation-user-interaction");
var instrumentation_xml_http_request_1 = require("@opentelemetry/instrumentation-xml-http-request");
var resources_1 = require("@opentelemetry/resources");
var sdk_trace_base_1 = require("@opentelemetry/sdk-trace-base");
var sdk_trace_web_1 = require("@opentelemetry/sdk-trace-web");
var semantic_conventions_1 = require("@opentelemetry/semantic-conventions");
var agent_exporter_1 = require("./otel/agent-exporter");
function getDefaultOTELInstrumentations(ignoreUrls) {
    if (ignoreUrls === void 0) { ignoreUrls = []; }
    return [
        new instrumentation_document_load_1.DocumentLoadInstrumentation(),
        new instrumentation_fetch_1.FetchInstrumentation({ ignoreUrls: ignoreUrls }),
        new instrumentation_xml_http_request_1.XMLHttpRequestInstrumentation({ ignoreUrls: ignoreUrls }),
        new instrumentation_user_interaction_1.UserInteractionInstrumentation(),
    ];
}
exports.getDefaultOTELInstrumentations = getDefaultOTELInstrumentations;
var TracingInstrumentation = /** @class */ (function (_super) {
    __extends(TracingInstrumentation, _super);
    function TracingInstrumentation(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this) || this;
        _this.options = options;
        _this.name = '@grafana/agent-tracing-web';
        _this.version = agent_core_1.VERSION;
        return _this;
    }
    TracingInstrumentation.prototype.initialize = function () {
        var _a, _b, _c, _d;
        var config = this.agent.config;
        var options = this.options;
        var attributes = {};
        if (config.app.name) {
            attributes[semantic_conventions_1.SemanticResourceAttributes.SERVICE_NAME] = config.app.name;
        }
        if (config.app.version) {
            attributes[semantic_conventions_1.SemanticResourceAttributes.SERVICE_VERSION] = config.app.version;
        }
        Object.assign(attributes, options.resourceAttributes);
        var resource = resources_1.Resource.default().merge(new resources_1.Resource(attributes));
        var provider = new sdk_trace_web_1.WebTracerProvider({ resource: resource });
        provider.addSpanProcessor((_a = options.spanProcessor) !== null && _a !== void 0 ? _a : new sdk_trace_base_1.BatchSpanProcessor(new agent_exporter_1.GrafanaAgentTraceExporter({ agent: agent_core_1.agent }), {
            scheduledDelayMillis: TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS,
        }));
        provider.register({
            propagator: (_b = options.propagator) !== null && _b !== void 0 ? _b : new core_1.W3CTraceContextPropagator(),
            contextManager: (_c = options.contextManager) !== null && _c !== void 0 ? _c : new context_zone_1.ZoneContextManager(),
        });
        (0, instrumentation_1.registerInstrumentations)({
            instrumentations: ((_d = options.instrumentations) === null || _d === void 0 ? void 0 : _d.length)
                ? options.instrumentations
                : getDefaultOTELInstrumentations(this.getIgnoreUrls()),
        });
        agent_core_1.agent.api.initOTEL(api_1.trace, api_1.context);
    };
    TracingInstrumentation.prototype.getIgnoreUrls = function () {
        return this.agent.transports.transports.flatMap(function (transport) { return transport.getIgnoreUrls(); });
    };
    TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS = 1000;
    return TracingInstrumentation;
}(agent_core_1.BaseInstrumentation));
exports.TracingInstrumentation = TracingInstrumentation;
//# sourceMappingURL=instrumentation.js.map