var __extends =
  (this && this.__extends) ||
  (function () {
    var extendStatics = function (d, b) {
      extendStatics =
        Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array &&
          function (d, b) {
            d.__proto__ = b;
          }) ||
        function (d, b) {
          for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p];
        };
      return extendStatics(d, b);
    };
    return function (d, b) {
      if (typeof b !== 'function' && b !== null)
        throw new TypeError('Class extends value ' + String(b) + ' is not a constructor or null');
      extendStatics(d, b);
      function __() {
        this.constructor = d;
      }
      d.prototype = b === null ? Object.create(b) : ((__.prototype = b.prototype), new __());
    };
  })();
import { BaseInstrumentation, VERSION, agent } from '@grafana/agent-core';
import { trace, context } from '@opentelemetry/api';
import { ZoneContextManager } from '@opentelemetry/context-zone';
import { W3CTraceContextPropagator } from '@opentelemetry/core';
import { registerInstrumentations } from '@opentelemetry/instrumentation';
import { DocumentLoadInstrumentation } from '@opentelemetry/instrumentation-document-load';
import { FetchInstrumentation } from '@opentelemetry/instrumentation-fetch';
import { UserInteractionInstrumentation } from '@opentelemetry/instrumentation-user-interaction';
import { XMLHttpRequestInstrumentation } from '@opentelemetry/instrumentation-xml-http-request';
import { Resource } from '@opentelemetry/resources';
import { BatchSpanProcessor } from '@opentelemetry/sdk-trace-base';
import { WebTracerProvider } from '@opentelemetry/sdk-trace-web';
import { SemanticResourceAttributes } from '@opentelemetry/semantic-conventions';
import { GrafanaAgentTraceExporter } from './otel/agent-exporter';
export function getDefaultOTELInstrumentations(ignoreUrls) {
  if (ignoreUrls === void 0) {
    ignoreUrls = [];
  }
  return [
    new DocumentLoadInstrumentation(),
    new FetchInstrumentation({ ignoreUrls: ignoreUrls }),
    new XMLHttpRequestInstrumentation({ ignoreUrls: ignoreUrls }),
    new UserInteractionInstrumentation(),
  ];
}
var TracingInstrumentation = /** @class */ (function (_super) {
  __extends(TracingInstrumentation, _super);
  function TracingInstrumentation(options) {
    if (options === void 0) {
      options = {};
    }
    var _this = _super.call(this) || this;
    _this.options = options;
    _this.name = '@grafana/agent-tracing-web';
    _this.version = VERSION;
    return _this;
  }
  TracingInstrumentation.prototype.initialize = function () {
    var _a, _b, _c, _d;
    var config = this.agent.config;
    var options = this.options;
    var attributes = {};
    if (config.app.name) {
      attributes[SemanticResourceAttributes.SERVICE_NAME] = config.app.name;
    }
    if (config.app.version) {
      attributes[SemanticResourceAttributes.SERVICE_VERSION] = config.app.version;
    }
    Object.assign(attributes, options.resourceAttributes);
    var resource = Resource.default().merge(new Resource(attributes));
    var provider = new WebTracerProvider({ resource: resource });
    provider.addSpanProcessor(
      (_a = options.spanProcessor) !== null && _a !== void 0
        ? _a
        : new BatchSpanProcessor(new GrafanaAgentTraceExporter({ agent: agent }), {
            scheduledDelayMillis: TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS,
          })
    );
    provider.register({
      propagator: (_b = options.propagator) !== null && _b !== void 0 ? _b : new W3CTraceContextPropagator(),
      contextManager: (_c = options.contextManager) !== null && _c !== void 0 ? _c : new ZoneContextManager(),
    });
    registerInstrumentations({
      instrumentations: ((_d = options.instrumentations) === null || _d === void 0 ? void 0 : _d.length)
        ? options.instrumentations
        : getDefaultOTELInstrumentations(this.getIgnoreUrls()),
    });
    agent.api.initOTEL(trace, context);
  };
  TracingInstrumentation.prototype.getIgnoreUrls = function () {
    return this.agent.transports.transports.flatMap(function (transport) {
      return transport.getIgnoreUrls();
    });
  };
  TracingInstrumentation.SCHEDULED_BATCH_DELAY_MS = 1000;
  return TracingInstrumentation;
})(BaseInstrumentation);
export { TracingInstrumentation };
//# sourceMappingURL=instrumentation.js.map
